<?php
/**
 * Copyright (C) 2019 Leipzig University Library
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @author  Alexander Purr <purr@ub.uni-leipzig.de>
 * @license http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 */

use fid\Hydrator\OrderHydrator;
use Zend\Filter\StringTrim;
use Zend\Form\Element\Submit;
use Zend\Form\Element\Text;
use Zend\Validator\Regex;
use Zend\Validator\StringLength;

return [
    'name'         => 'fid-acquisition-form',
    'hydrator'     => OrderHydrator::class,
    'elements'     => [
        'pages'              => [
            'spec' => [
                'name'       => 'pages',
                'type'       => Text::class,
                'options'    => [
                    'label' => 'label_acquisition_pages',
                ],
                'attributes' => [
                    'required' => true,
                ],
            ],
        ],
        'submit'               => [
            'spec' => [
                'name'       => 'submit',
                'type'       => Submit::class,
                'attributes' => [
                    'value' => 'label_acquisition_submit',
                ],
            ],
        ],
    ],
    'input_filter' => [
        'pages'              => [
            'name'       => 'pages',
            'filters'    => [
                StringTrim::class => [
                    'name' => StringTrim::class,
                ],
            ],
            'validators' => [
                StringLength::class => [
                    'name'    => StringLength::class,
                    'options' => [
                        'min'      => 3,
                        'max'      => 13,
                        'messages' => [
                            StringLength::TOO_SHORT => 'error_pages_length',
                            StringLength::TOO_LONG  => 'error_pages_length',
                        ],
                    ],
                ],
                Regex::class        => [
                    'name'    => Regex::class,
                    'options' => [
                        'pattern'  => '/^(0|[1-9]\d*)-([1-9]\d*)$/',
                        'messages' => [
                            Regex::NOT_MATCH => 'error_pages_pattern',
                        ],
                    ],
                ],
            ],
        ],
        'submit'               => [
            'name'     => 'submit',
            'required' => true,
        ],
    ],
];