<?php
/**
 * FID Acquisition Trait
 *
 * PHP version 5
 *
 * Copyright (C) Villanova University 2010.
 * Copyright (C) Leipzig University Library 2015.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind FID
 * @package  Controller
 * @author   Alexander Purr <purr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 */
namespace fid\Controller\CustomTraits;

use fid\Service\Client;
use fid\Service\DataTransferObject\Order;
use Zend\Form\Form;
use Zend\Http\PhpEnvironment\Request;

/**
 * FID Acquisition Trait
 *
 * @category VuFind
 * @package  Controller
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     http://finc.info   Main Site
 */
trait FidAcquisitionTrait
{
    /**
     * @var Client
     */
    protected $client;

    /**
     * @param Client $client
     */
    public function setClient(Client $client): void
    {
        $this->client = $client;
    }

    public function fidPdaAction ()
    {
        if (!($user = $this->getUser())) {
            return $this->forceLogin();
        }

        $type = "pda";
        $driver = $this->loadRecord();
        $recordId = $driver->tryMethod('getUniqueID');
        $messenger = $this->flashMessenger();

        /** @var Form $form */
        /** @var Request $request */
        $request = $this->getRequest();
        $form = $this->serviceLocator->get('fid-acquisition-form');

        if ($submitted = $this->formWasSubmitted()) {
            $form->setData($request->getPost());
            if ($form->isValid()) {
                $user = $this->client->requestUserDetails();
                $form->getHydrator()->hydrate(compact('driver','user', 'type'), $order = new Order());
                $response = $this->client->requestOrderCreation($order);
                $message = $this->translate('fid::aquisition_success');
                $messenger->addSuccessMessage($message);
                return $this->redirect()->toRoute('record',['id' => $recordId]);
            }
        }

        $patron = $this->catalogLogin();
        $catalog = $this->getILS();
        $profile = $catalog->getMyProfile($patron);

        $action = $this->url()->fromRoute('record-fidpda',['id' => $recordId]);
        $form->setAttribute('action', $action);
        $form->prepare();

        $view = $this->createViewModel();
        $view->setVariables(compact('form','driver','profile'));
        $view->setTemplate('fid/record/acquisition-pda');

        return $view;
    }

    public function fidSubitoArticleAction () {

        if (!($user = $this->getUser())) {
            return $this->forceLogin();
        }

        $type = "subito-article";
        $driver = $this->loadRecord();
        $recordId = $driver->tryMethod('getUniqueID');
        $messenger = $this->flashMessenger();

        /** @var Form $form */
        /** @var Request $request */
        $request = $this->getRequest();
        $form = $this->serviceLocator->get('fid-acquisition-form');

        if ($submitted = $this->formWasSubmitted()) {
            $form->setData($request->getPost());
            if ($form->isValid()) {
                $user = $this->client->requestUserDetails();
                $form->getHydrator()->hydrate(compact('driver','user', 'type'), $order = new Order());
                $response = $this->client->requestOrderCreation($order);
                $message = $this->translate('fid::aquisition_success');
                $messenger->addSuccessMessage($message);
                return $this->redirect()->toRoute('record',['id' => $recordId]);
            }
        }

        $patron = $this->catalogLogin();
        $catalog = $this->getILS();
        $profile = $catalog->getMyProfile($patron);

        $action = $this->url()->fromRoute('record-fidsubitoarticle',['id' => $recordId]);
        $form->setAttribute('action', $action);
        $form->prepare();

        $view = $this->createViewModel();
        $view->setVariables(compact('form','driver','profile'));
        $view->setTemplate('fid/record/acquisition-subito-article');

        return $view;
    }

    public function fidSubitoPartialCopyAction () {
        if (!($user = $this->getUser())) {
            return $this->forceLogin();
        }

        $type = "subito-partial-copy";
        $driver = $this->loadRecord();
        $recordId = $driver->tryMethod('getUniqueID');
        $messenger = $this->flashMessenger();

        /** @var Form $form */
        /** @var Request $request */
        $request = $this->getRequest();
        $form = $this->serviceLocator->get('fid-acquisition-subito-partial-copy-form');

        if ($submitted = $this->formWasSubmitted()) {
            $form->setData($request->getPost());
            if ($form->isValid()) {
                $user = $this->client->requestUserDetails();
                $pages = $form->getData()['pages'];
                $form->getHydrator()->hydrate(compact('driver','user', 'type','pages'), $order = new Order());
                $this->client->requestOrderCreation($order);
                $message = $this->translate('fid::aquisition_success');
                $messenger->addSuccessMessage($message);
                return $this->redirect()->toRoute('record',['id' => $recordId]);
            }
        }

        $patron = $this->catalogLogin();
        $catalog = $this->getILS();
        $profile = $catalog->getMyProfile($patron);

        $action = $this->url()->fromRoute('record-fidsubitopartialcopy',['id' => $recordId]);
        $form->setAttribute('action', $action);
        $form->prepare();

        $view = $this->createViewModel();
        $view->setVariables(compact('form','driver','profile'));
        $view->setTemplate('fid/record/acquisition-subito-partial-copy');

        return $view;
    }

}
