<?php
/**
 * Copyright (C) 2019 Leipzig University Library
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @author  Sebastian Kehr <kehr@ub.uni-leipzig.de>
 * @license http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 */

namespace fid\Service\DataTransferObject;

namespace fid\Service\DataTransferObject;

use Symfony\Component\Serializer\Annotation\Groups;

class Order
{
    /**
     * @var string|null
     * @Groups({
     *     "order:creation:response",
     *     "order:list:response",
     *     "user:details:response",
     *     "user:creation:response",
     *     "user:update:response"
     * })
     */
    protected $id;

    /**
     * @var string
     * @Groups({
     *     "order:creation:request",
     *     "order:creation:response",
     *     "order:list:response",
     *     "user:details:response",
     *     "user:creation:response",
     *     "user:update:response"
     * })
     */
    protected $type = '';

    /**
     * @var User|null
     * @Groups({
     *     "order:creation:request",
     *     "order:creation:response",
     *     "order:list:response",
     *     "user:details:response",
     *     "user:creation:response",
     *     "user:update:response"
     * })
     */
    protected $user;

    /**
     * @var array
     * @Groups({
     *     "order:creation:request",
     *     "order:creation:response",
     *     "order:list:response",
     *     "user:details:response",
     *     "user:creation:response",
     *     "user:update:response"
     * })
     */
    protected $data = [];

    /**
     * @var \DateTime
     * @Groups({
     *     "order:creation:response",
     *     "order:list:response",
     *     "user:details:response",
     *     "user:creation:response",
     *     "user:update:response"
     * })
     */
    protected $createdAt;

    /**
     * @return string|null
     */
    public function getId(): ?string
    {
        return $this->id;
    }

    /**
     * @param string|null $id
     */
    public function setId(?string $id): void
    {
        $this->id = $id;
    }

    /**
     * @return string
     */
    public function getType(): string
    {
        return $this->type;
    }

    /**
     * @param string $type
     */
    public function setType(string $type): void
    {
        $this->type = $type;
    }

    /**
     * @return User|null
     */
    public function getUser(): ?User
    {
        return $this->user;
    }

    /**
     * @param User|null $user
     */
    public function setUser(?User $user): void
    {
        $this->user = $user;
    }

    /**
     * @return array
     */
    public function getData(): array
    {
        return $this->data;
    }

    /**
     * @param array $data
     */
    public function setData(array $data): void
    {
        $this->data = $data;
    }

    /**
     * @return \DateTime
     */
    public function getCreatedAt(): \DateTime
    {
        return $this->createdAt;
    }

    /**
     * @param \DateTime $createdAt
     */
    public function setCreatedAt(\DateTime $createdAt): void
    {
        $this->createdAt = $createdAt;
    }
}