<?php
/**
 * Factory for record driver data formatting view helper
 *
 * PHP version 7
 *
 * Copyright (C) Villanova University 2016.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind FID
 * @package  View_Helpers
 * @author   Alexander Purr <purr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 */
namespace fid\View\Helper\Root;

use VuFind\View\Helper\Root\RecordDataFormatter;

class RecordDataFormatterFactory
{
    /**
     * Create the helper.
     *
     * @return RecordDataFormatter
     */
    public function __invoke()
    {
        $helper = new RecordDataFormatter();

        $helper->setDefaults('fid-acquisition-general', [$this, 'getFidAcquisitionSpecs']);
        //$helper->setDefaults('fid-pda', [$this, 'getFidPdaSpecs']);
        //$helper->setDefaults('fid-subito-articel', [$this, 'getFidSubitoArticelSpecs']);
        //$helper->setDefaults('fid-subito-partial-copy', [$this, 'getFidSubitoPartialCopySpecs']);

        return $helper;
    }

    /**
     * Get specifications for displaying data in fid pda form.
     *
     * @return array
     */
    public function getFidAcquisitionSpecs()
    {
        $spec = new RecordDataFormatter\SpecBuilder();
        $spec->setLine('Title','getTitle');
        $spec->setTemplateLine(
            'Authors/Corporations',
            'getDeduplicatedAuthors',
            'data-authors.phtml',
            [
                'useCache' => true,
                'context' => [
                    'requiredDataFields' => [
                        ['name' => 'role', 'prefix' => 'CreatorRoles::']
                    ]
                ]
            ]
        );
        $spec->setTemplateLine(
            'Published',
            'getPublicationDetails',
            'data-publicationDetails.phtml'
        );
        $spec->setTemplateLine(
            'Price',
            'getPrice',
            'data-price.phtml'
        );
        $spec->setLine('Language','getLanguages');
        return $spec->getArray();
    }
}
